==> pgConflux-v0.2.tar.gz: pgConflux-v0.2/conflux--0.1--0.2.sql <==

DROP OPERATOR CLASS pstamp_ops USING gist;
DROP OPERATOR && (pstamp, pstamp_query);
DROP OPERATOR && (pstamp_query, pstamp);
DROP OPERATOR <-> (pstamp, pstamp_query);
DROP OPERATOR <-> (pstamp_query, pstamp);


CREATE OR REPLACE FUNCTION pstamp_key_in_dummy(cstring)
  RETURNS pstamp_key
  LANGUAGE C IMMUTABLE STRICT
  AS '$libdir/conflux-v0002', 'cfl_notimpl';

CREATE OR REPLACE FUNCTION pstamp_key_out_dummy(pstamp_key)
  RETURNS cstring
  LANGUAGE C IMMUTABLE STRICT
  AS '$libdir/conflux-v0002', 'cfl_notimpl';


CREATE OR REPLACE FUNCTION pstamp_in(cstring)
  RETURNS pstamp
  LANGUAGE C IMMUTABLE STRICT
  AS '$libdir/conflux-v0002', 'cfl_pstamp_in';

CREATE OR REPLACE FUNCTION pstamp_out(pstamp)
  RETURNS cstring
  LANGUAGE C IMMUTABLE STRICT
  AS '$libdir/conflux-v0002', 'cfl_pstamp_out';

CREATE OR REPLACE FUNCTION pstamp_recv(internal)
  RETURNS pstamp
  LANGUAGE C IMMUTABLE STRICT
  AS '$libdir/conflux-v0002', 'cfl_pstamp_recv';

CREATE OR REPLACE FUNCTION pstamp_send(pstamp)
  RETURNS bytea
  LANGUAGE C IMMUTABLE STRICT
  AS '$libdir/conflux-v0002', 'cfl_pstamp_send';

CREATE OR REPLACE FUNCTION pstamp_query_in(cstring)
  RETURNS pstamp_query
  LANGUAGE C IMMUTABLE STRICT
  AS '$libdir/conflux-v0002', 'cfl_pstamp_query_in';

CREATE OR REPLACE FUNCTION pstamp_query_out(pstamp_query)
  RETURNS cstring
  LANGUAGE C IMMUTABLE STRICT
  AS '$libdir/conflux-v0002', 'cfl_pstamp_query_out';


CREATE OR REPLACE FUNCTION pstamp(int4, int8)
  RETURNS pstamp
  LANGUAGE C IMMUTABLE STRICT
  AS '$libdir/conflux-v0002', 'cfl_pstamp_new';

CREATE OR REPLACE FUNCTION pstamp_query(int4[], int8 = 1e15::int8)
  RETURNS pstamp_query
  LANGUAGE C IMMUTABLE STRICT
  AS '$libdir/conflux-v0002', 'cfl_pstamp_query_new';


CREATE OR REPLACE FUNCTION pstamp_match_proc(pstamp, pstamp_query)
  RETURNS boolean
  LANGUAGE C IMMUTABLE STRICT
  AS '$libdir/conflux-v0002', 'cfl_pstamp_match';

CREATE OPERATOR <| (
  leftarg = pstamp,
  rightarg = pstamp_query,
  procedure = pstamp_match_proc,
  commutator = |>,
  restrict = eqsel,
  join = eqjoinsel
);

CREATE OR REPLACE FUNCTION pstamp_match_commutator(pstamp_query, pstamp)
  RETURNS boolean
  LANGUAGE sql IMMUTABLE AS 'SELECT $2 <| $1';

CREATE OPERATOR |> (
  leftarg = pstamp_query,
  rightarg = pstamp,
  procedure = pstamp_match_commutator,
  commutator = <|,
  restrict = eqsel,
  join = eqjoinsel
);

CREATE OR REPLACE FUNCTION pstamp_distance_proc(pstamp, pstamp_query)
  RETURNS float8
  LANGUAGE C IMMUTABLE STRICT
  AS '$libdir/conflux-v0002', 'cfl_pstamp_distance';

CREATE OPERATOR <-| (
  leftarg = pstamp,
  rightarg = pstamp_query,
  procedure = pstamp_distance_proc,
  commutator = |->
);

CREATE OR REPLACE FUNCTION pstamp_distance_commutator(pstamp_query, pstamp)
  RETURNS float8
  LANGUAGE sql IMMUTABLE AS 'SELECT $2 <-| $1';

CREATE OPERATOR |-> (
  leftarg = pstamp_query,
  rightarg = pstamp,
  procedure = pstamp_distance_commutator,
  commutator = <-|
);


CREATE OR REPLACE FUNCTION cfl_gist_pstamp_consistent(internal)
  RETURNS internal
  LANGUAGE C IMMUTABLE STRICT
  AS '$libdir/conflux-v0002', 'cfl_gist_pstamp_consistent';

CREATE OR REPLACE FUNCTION cfl_gist_pstamp_union(internal)
  RETURNS internal
  LANGUAGE C STRICT
  AS '$libdir/conflux-v0002', 'cfl_gist_pstamp_union';

CREATE OR REPLACE FUNCTION cfl_gist_pstamp_compress(internal)
  RETURNS internal
  LANGUAGE C STRICT
  AS '$libdir/conflux-v0002', 'cfl_gist_pstamp_compress';

CREATE OR REPLACE FUNCTION cfl_gist_decompress(internal)
  RETURNS internal
  LANGUAGE C STRICT
  AS '$libdir/conflux-v0002', 'cfl_gist_decompress';

CREATE OR REPLACE FUNCTION cfl_gist_pstamp_penalty(internal)
  RETURNS internal
  LANGUAGE C STRICT
  AS '$libdir/conflux-v0002', 'cfl_gist_pstamp_penalty';

CREATE OR REPLACE FUNCTION cfl_gist_pstamp_picksplit(internal)
  RETURNS internal
  LANGUAGE C STRICT
  AS '$libdir/conflux-v0002', 'cfl_gist_pstamp_picksplit';

CREATE OR REPLACE FUNCTION cfl_gist_pstamp_same(internal)
  RETURNS internal
  LANGUAGE C STRICT
  AS '$libdir/conflux-v0002', 'cfl_gist_pstamp_same';

CREATE OR REPLACE FUNCTION cfl_gist_pstamp_distance(internal)
  RETURNS internal
  LANGUAGE C STRICT
  AS '$libdir/conflux-v0002', 'cfl_gist_pstamp_distance';

CREATE OPERATOR CLASS pstamp_ops
  DEFAULT FOR TYPE pstamp USING gist AS
  OPERATOR 1 <|  (pstamp, pstamp_query),
  OPERATOR 2 <-| (pstamp, pstamp_query) FOR ORDER BY float_ops,
  FUNCTION 1 cfl_gist_pstamp_consistent(internal),
  FUNCTION 2 cfl_gist_pstamp_union(internal),
  FUNCTION 3 cfl_gist_pstamp_compress(internal),
  FUNCTION 4 cfl_gist_decompress(internal),
  FUNCTION 5 cfl_gist_pstamp_penalty(internal),
  FUNCTION 6 cfl_gist_pstamp_picksplit(internal),
  FUNCTION 7 cfl_gist_pstamp_same(internal),
  FUNCTION 8 cfl_gist_pstamp_distance(internal),
  STORAGE pstamp_key;

==> pgConflux-v0.3.tar.gz: pgConflux-v0.3/conflux--0.2--0.3.sql <==

CREATE OR REPLACE FUNCTION pstamp_key_in_dummy(cstring)
  RETURNS pstamp_key
  LANGUAGE C IMMUTABLE STRICT
  AS '$libdir/conflux-v0003', 'cfl_notimpl';

CREATE OR REPLACE FUNCTION pstamp_key_out_dummy(pstamp_key)
  RETURNS cstring
  LANGUAGE C IMMUTABLE STRICT
  AS '$libdir/conflux-v0003', 'cfl_notimpl';

CREATE OR REPLACE FUNCTION pstamp_in(cstring)
  RETURNS pstamp
  LANGUAGE C IMMUTABLE STRICT
  AS '$libdir/conflux-v0003', 'cfl_pstamp_in';

CREATE OR REPLACE FUNCTION pstamp_out(pstamp)
  RETURNS cstring
  LANGUAGE C IMMUTABLE STRICT
  AS '$libdir/conflux-v0003', 'cfl_pstamp_out';

CREATE OR REPLACE FUNCTION pstamp_recv(internal)
  RETURNS pstamp
  LANGUAGE C IMMUTABLE STRICT
  AS '$libdir/conflux-v0003', 'cfl_pstamp_recv';

CREATE OR REPLACE FUNCTION pstamp_send(pstamp)
  RETURNS bytea
  LANGUAGE C IMMUTABLE STRICT
  AS '$libdir/conflux-v0003', 'cfl_pstamp_send';

CREATE OR REPLACE FUNCTION pstamp_query_in(cstring)
  RETURNS pstamp_query
  LANGUAGE C IMMUTABLE STRICT
  AS '$libdir/conflux-v0003', 'cfl_pstamp_query_in';

CREATE OR REPLACE FUNCTION pstamp_query_out(pstamp_query)
  RETURNS cstring
  LANGUAGE C IMMUTABLE STRICT
  AS '$libdir/conflux-v0003', 'cfl_pstamp_query_out';

CREATE OR REPLACE FUNCTION pstamp(int4, int8)
  RETURNS pstamp
  LANGUAGE C IMMUTABLE STRICT
  AS '$libdir/conflux-v0003', 'cfl_pstamp_new';

CREATE OR REPLACE FUNCTION pstamp_query(int4[], int8 = 1e15::int8)
  RETURNS pstamp_query
  LANGUAGE C IMMUTABLE STRICT
  AS '$libdir/conflux-v0003', 'cfl_pstamp_query_new';

CREATE OR REPLACE FUNCTION pstamp_query(int4, int8 = 1e15::int8)
  RETURNS pstamp_query
  LANGUAGE SQL IMMUTABLE STRICT
  AS 'SELECT pstamp_query(ARRAY[$1], $2)';

CREATE OR REPLACE FUNCTION pstamp_match_proc(pstamp, pstamp_query)
  RETURNS boolean
  LANGUAGE C IMMUTABLE STRICT
  AS '$libdir/conflux-v0003', 'cfl_pstamp_match';

CREATE OR REPLACE FUNCTION pstamp_distance_proc(pstamp, pstamp_query)
  RETURNS float8
  LANGUAGE C IMMUTABLE STRICT
  AS '$libdir/conflux-v0003', 'cfl_pstamp_distance';

CREATE OR REPLACE FUNCTION cfl_gist_pstamp_consistent(internal)
  RETURNS internal
  LANGUAGE C IMMUTABLE STRICT
  AS '$libdir/conflux-v0003', 'cfl_gist_pstamp_consistent';

CREATE OR REPLACE FUNCTION cfl_gist_pstamp_union(internal)
  RETURNS internal
  LANGUAGE C STRICT
  AS '$libdir/conflux-v0003', 'cfl_gist_pstamp_union';

CREATE OR REPLACE FUNCTION cfl_gist_pstamp_compress(internal)
  RETURNS internal
  LANGUAGE C STRICT
  AS '$libdir/conflux-v0003', 'cfl_gist_pstamp_compress';

CREATE OR REPLACE FUNCTION cfl_gist_decompress(internal)
  RETURNS internal
  LANGUAGE C STRICT
  AS '$libdir/conflux-v0003', 'cfl_gist_decompress';

CREATE OR REPLACE FUNCTION cfl_gist_pstamp_penalty(internal)
  RETURNS internal
  LANGUAGE C STRICT
  AS '$libdir/conflux-v0003', 'cfl_gist_pstamp_penalty';

CREATE OR REPLACE FUNCTION cfl_gist_pstamp_picksplit(internal)
  RETURNS internal
  LANGUAGE C STRICT
  AS '$libdir/conflux-v0003', 'cfl_gist_pstamp_picksplit';

CREATE OR REPLACE FUNCTION cfl_gist_pstamp_same(internal)
  RETURNS internal
  LANGUAGE C STRICT
  AS '$libdir/conflux-v0003', 'cfl_gist_pstamp_same';

CREATE OR REPLACE FUNCTION cfl_gist_pstamp_distance(internal)
  RETURNS internal
  LANGUAGE C STRICT
  AS '$libdir/conflux-v0003', 'cfl_gist_pstamp_distance';
